"""Views for the admin_keyboard_shortcuts app."""
# from django.views.generic import TemplateView

# from . import models


# class YourView(TemplateView):
#    template_name = 'admin_keyboard_shortcuts/default.html'
